#exonware/xwjson/src/xwjson.py
"""
Convenience alias for exonware.xwjson
This module provides a convenient import path:
    from xwjson import XWJSONSerializer
Instead of:
    from exonware.xwjson import XWJSONSerializer
"""

